@@ -4,7 +4,7 @@ test_that("ClinicalTrials.gov history entries mass-download correctly", {
         file.remove(filename)
     }
     result <- clinicaltrials_gov_download(
-        c("NCT00942747", "NCT04796324"), filename
+        c("NCT02329873"), filename, TRUE
     )
     expect_equal(
         result == TRUE || result == FALSE,
